@@ -1,10 +1,10 @@
 from __future__ import unicode_literals
 
 __title__ = "dj-stripe"
-__summary__ = "Django + Stripe for humans "
+__summary__ = "Django + Stripe Made Easy"
 __uri__ = "https://github.com/pydanny/dj-stripe/"
 
-__version__ = "0.2.2"
+__version__ = "0.2.6"
 
 __author__ = "Daniel Greenfeld"
 __email__ = "pydanny@gmail.com"
